@@ -366,6 +366,193 @@ class TestBlocksCaption(util.MdCase):
             True
         )
 
+    def test_table_caption_multiple_inline_id_not_allowed(self):
+        """Ensure multiple inline shorthand IDs are rejected."""
+
+        self.check_markdown(
+            R"""
+            Paragraph
+            /// table-caption | #id1#id2
+            Table caption text.
+            ///
+            """,
+            """
+            <p>Paragraph
+            /// table-caption | #id1#id2
+            Table caption text.
+            ///</p>
+            """,
+            True
+        )
+
+    def test_caption_inline_class_invalid_identifier(self):
+        """Ensure inline shorthand classes with invalid characters is rejected."""
+
+        self.check_markdown(
+            R"""
+            Paragraph
+            /// figure-caption | .invalid!
+            Caption text.
+            ///
+            """,
+            """
+            <p>Paragraph
+            /// figure-caption | .invalid!
+            Caption text.
+            ///</p>
+            """,
+            True
+        )
+
+    def test_caption_inline_class(self):
+        """Test caption with inline shorthand class."""
+
+        self.check_markdown(
+            R'''
+            Paragraph
+            /// figure-caption | .custom-class
+            Caption text.
+            ///
+            ''',
+            R'''
+            <figure class="custom-class">
+            <p>Paragraph</p>
+            <figcaption>
+            <p>Caption text.</p>
+            </figcaption>
+            </figure>
+            ''',
+            True
+        )
+
+    def test_caption_multiple_inline_class(self):
+        """Test caption with multiple inline shorthand class."""
+
+        self.check_markdown(
+            R'''
+            Paragraph
+            /// figure-caption | .custom-class1.custom-class2
+            Caption text.
+            ///
+            ''',
+            R'''
+            <figure class="custom-class1 custom-class2">
+            <p>Paragraph</p>
+            <figcaption>
+            <p>Caption text.</p>
+            </figcaption>
+            </figure>
+            ''',
+            True
+        )
+
+    def test_caption_inline_class_and_id(self):
+        """Test caption with inline shorthand class and id."""
+
+        self.check_markdown(
+            R'''
+            Paragraph
+            /// figure-caption | .custom-class#custom-id
+            Caption text.
+            ///
+            ''',
+            R'''
+            <figure class="custom-class" id="custom-id">
+            <p>Paragraph</p>
+            <figcaption>
+            <p>Caption text.</p>
+            </figcaption>
+            </figure>
+            ''',
+            True
+        )
+
+    def test_caption_inline_class_attribute_merge(self):
+        """Ensure inline shorthand class merges with attribute-defined class."""
+
+        self.check_markdown(
+            R'''
+            Paragraph
+            /// figure-caption | .inline-class
+                attrs: {class: attribute-class}
+            Caption text.
+            ///
+            ''',
+            R'''
+            <figure class="attribute-class inline-class">
+            <p>Paragraph</p>
+            <figcaption>
+            <p>Caption text.</p>
+            </figcaption>
+            </figure>
+            ''',
+            True
+        )
+
+    def test_caption_inline_class_unique(self):
+        """Ensure inline shorthand classes are unique."""
+
+        self.check_markdown(
+            R'''
+            Paragraph
+            /// figure-caption | .custom-class.custom-class
+            Caption text.
+            ///
+            ''',
+            R'''
+            <figure class="custom-class">
+            <p>Paragraph</p>
+            <figcaption>
+            <p>Caption text.</p>
+            </figcaption>
+            </figure>
+            ''',
+            True
+        )
+
+    def test_caption_inline_class_attribute_unique(self):
+        """Ensure inline shorthand classes and attribute classes are unique after merging."""
+
+        self.check_markdown(
+            R'''
+            Paragraph
+            /// figure-caption | .custom-class
+                attrs: {class: custom-class}
+            Caption text.
+            ///
+            ''',
+            R'''
+            <figure class="custom-class">
+            <p>Paragraph</p>
+            <figcaption>
+            <p>Caption text.</p>
+            </figcaption>
+            </figure>
+            ''',
+            True
+        )
+
+    def test_caption_inline_arbitrary_attribute(self):
+        """Ensure inline shorthand classes and attribute classes are unique after merging."""
+
+        self.check_markdown(
+            R'''
+            Paragraph
+            /// figure-caption | .custom-class[data="test"]
+            Caption text.
+            ///
+            ''',
+            R'''
+            <figure class="custom-class" data="test">
+            <p>Paragraph</p>
+            <figcaption>
+            <p>Caption text.</p>
+            </figcaption>
+            </figure>
+            ''',
+            True
+        )
+
 
 class TestBlocksCaptionClass(util.MdCase):
     """Test caption classes."""
